#' An \code{htmlwidget} interface to the
#' billboard.js javascript chart library
#' 
#' This package allow you to use billboard.js (\url{https://naver.github.io/billboard.js/}),
#' a re-usable easy interface JavaScript chart library, based on D3 v4+.
#' 
#' @name billboarder-package
#' @docType package
#' @author Victor Perrier (@@dreamRs_fr)
NULL

#' billboarder exported operators and S3 methods
#' 
#' The following functions are imported and then re-exported
#' from the billboarder package to avoid listing the magrittr
#' as Depends of billboarder
#' 
#' @name billboarder-exports
NULL

#' @importFrom magrittr %>%
#' @name %>%
#' @export
#' @rdname billboarder-exports
NULL

#' @importFrom htmlwidgets JS
#' @name JS
#' @export
#' @rdname billboarder-exports
NULL